# Pylunch - Lunch scraper for Brno

Pyluch is a simple scaper for a daily lunch menus.

## Getting started

Currently pulunch is under development so it is not available on the [Pypi](https://pypi.org/).

Development version you can get using the Git.

```bash
$ git clone https://gitlab.com/pestanko/pylunch.git
$ cd pylunch
```

Project dependencies can be installed using the [Pipenv](https://docs.pipenv.org/).

```bash
$ pipenv install
```

To run the pylunch command line interface just use the `python` via the `pipenv`:

```bash
pipenv run python -m pylunch.cli -h     # shows help
```
